package com.gihon.common.swagger;

import com.github.xiaoymin.knife4j.spring.annotations.EnableKnife4j;
import com.google.common.collect.Lists;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.web.context.WebServerInitializedEvent;
import org.springframework.context.ApplicationListener;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import org.springframework.security.access.method.P;
import springfox.bean.validators.configuration.BeanValidatorPluginsConfiguration;
import springfox.documentation.builders.*;
import springfox.documentation.schema.ScalarType;
import springfox.documentation.service.Parameter;
import springfox.documentation.schema.ModelRef;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.ParameterType;
import springfox.documentation.service.RequestParameter;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

import java.net.Inet4Address;
import java.net.InetAddress;
import java.util.List;

/**
 * Knife4j配置
 */
@Configuration
@EnableSwagger2
@EnableKnife4j
@Import(BeanValidatorPluginsConfiguration.class)
public class Knife4jConfig implements ApplicationListener<WebServerInitializedEvent> {

    private static Logger logger = LoggerFactory.getLogger(Knife4jConfig.class);

    @Bean(value = "web")
    public Docket createRestAdmin() {
        // 添加请求参数，我们这里把token作为请求头部参数传入后端(defaultValue还不能使用具体问题不祥)
        RequestParameter parameter = new RequestParameterBuilder().name("Authorization").in(ParameterType.HEADER).query(x->x.defaultValue("token")).build();
        List<RequestParameter> parameters = Lists.newArrayList();
        parameters.add(parameter);
        return new Docket(DocumentationType.SWAGGER_2)
                .useDefaultResponseMessages(false)
                .groupName("web")
                .apiInfo(apiInfo())
                .globalRequestParameters(parameters)
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.gihon.controller"))
                .paths(PathSelectors.any())
                .build();

    }

    private ApiInfo apiInfo() {
        return new ApiInfoBuilder()
                .title("权限验证")
                .build();
    }

    @Override
    public void onApplicationEvent(WebServerInitializedEvent event) {
        try {
            InetAddress inetAddress = Inet4Address.getLocalHost();
            logger.info("\033[1;33m项目启动成功！接口文档地址: http://" + inetAddress.getHostAddress() + ":" + event.getWebServer().getPort() + event.getApplicationContext().getEnvironment().getProperty("server.servlet.context-path") + "/doc.html\033[0m");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}