package com.gihon.configSecurity.config;

import com.gihon.configSecurity.service.impl.UserLoginServiceImpl;
import com.gihon.sso.entity.vo.UserInfo;
import com.gihon.sso.service.TokenService;
import com.gihon.sso.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.web.authentication.WebAuthenticationDetailsSource;
import org.springframework.stereotype.Component;
import org.springframework.web.filter.OncePerRequestFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

@Component
public class AuthenticationTokenFilter extends OncePerRequestFilter {

    @Autowired
    private UserLoginServiceImpl userLoginService; //用户信息service
    @Autowired
    private TokenService tokenService;

    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain chain) throws ServletException, IOException {
        String authHeader = request.getHeader("Authorization");;//获取header中的验证信息
        if (authHeader != null) {
            UserInfo userInfo = tokenService.checkTokenInfo(authHeader); //从token中获取用户信息
            if (userInfo.getUserName() != null && SecurityContextHolder.getContext().getAuthentication() == null) {
                UserDetails userDetails = userLoginService.loadUserByUsername(userInfo.getUserName());//根据用户名获取用户对象
                if (userDetails != null) {
                    UsernamePasswordAuthenticationToken authentication =
                            new UsernamePasswordAuthenticationToken(userDetails, null, userDetails.getAuthorities());
                    authentication.setDetails(new WebAuthenticationDetailsSource().buildDetails(request));
                    //设置为已登录
                    SecurityContextHolder.getContext().setAuthentication(authentication);
                }
            }
        }
        chain.doFilter(request, response);
    }
}