package com.gihon.controller;

import com.gihon.common.web.response.PageResponse;
import com.gihon.common.web.response.Response;
import com.gihon.entity.Permission;
import com.gihon.service.permissionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * @program: common-parent
 * @description:
 * @author: dl
 * @create: 02月19日 09时
 **/
@Api(value = "权限接口", tags = "权限接口")
@RequestMapping("/Permission")
@RestController
public class PermissionController {
    @Autowired
    private permissionService permissionService;
    /**
     * 处理内容： 查看用户权限
     * @param id 用户id
     * @return 用户拥有的权限列表
     */
    @GetMapping("/getPermissionsByUserId")
    @ApiOperation("根据用户id 查看 用户权限信息")
    public Response<Permission> getPermission(Long id){
        Response permissions = permissionService.getPermissionsByUserId(id);
        return permissions;
    }
    @GetMapping("/modifyPermission")
    @ApiOperation("根据权限id 修改权限名称")
    public Response modifyPermission(Long id ,String permissionStr){
        Response modifyPermission = permissionService.modifyPermission(id, permissionStr);
        return modifyPermission;
    }
    /**
     * 主要功能：
     * @description 根据id 查找权限信息
     * @author: dl
     * @data 2021/2/23 15:33
     * @param	id
     * @return com.gihon.common.web.response.Response
     */
    @ApiOperation("根据权限id 查找权限信息")
    @GetMapping("/getPermissionById")
    public Response getPermissionById(Long id){
        Response response = permissionService.getpermissionById(id);
        return response;
    }


    @GetMapping("/deletePermissionById")
    @ApiOperation("根据权限id 删除权限")
    public Response deletePermissionById(Long id){
        Response response = permissionService.deletePermissionById(id);
        return response;
    }
    @GetMapping("/addPermission")
    @ApiOperation("增加权限")
    public Response addPermission(Permission permission){
        Response response = permissionService.addPermissionById(permission);
        return response;
    }
    @GetMapping("/pagePermission")
    @ApiOperation("分页查询权限")
    public PageResponse<Permission> pagePermissions(
            @RequestParam(required = false,defaultValue = "0") int page,
            @RequestParam(required = false, defaultValue = "10") int rows){
        PageResponse response = permissionService.pagePermissions(page,rows);
        return response;
    }

}
