package com.gihon.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gihon.common.web.response.PageBean;
import com.gihon.common.web.response.PageResponse;
import com.gihon.common.web.response.Response;
import com.gihon.common.web.response.ResponseStatus;
import com.gihon.entity.Permission;
import com.gihon.mapper.PermissionMapper;
import com.gihon.service.permissionService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @program: common-parent
 * @description:
 * @author: dl
 * @create: 02月20日 09时
 **/
@Service
public class permissionServiceImpl extends ServiceImpl<PermissionMapper,Permission> implements permissionService {
    /**
     * 主要功能：
     * @description 根据 用户id 查询所有权限
     * @author: dl
     * @data 2021/2/22 18:11
     * @param	id
     * @return com.gihon.common.web.response.Response<java.util.List<com.gihon.permission.entity.Permission>>
     */
    @Override
    public Response<List<Permission>> getPermissionsByUserId(Long id) {

        List<Permission> permissions = baseMapper.getPermissions(id);
        return Response.ok(permissions);
    }

    @Override
    public Response getpermissionById(Long id) {
        Permission byId = this.getById(id);
        return Response.ok(byId);
    }

    @Override
    public Response deletePermissionById(Long id) {
        boolean b = this.removeById(id);
        if (!b){
            return Response.error(ResponseStatus.MAPPER_ERROR,"删除失败");
        }
        return Response.ok();
    }

    @Override
    public Response addPermissionById(Permission permission) {
        boolean save = this.save(permission);
        if (!save){return Response.error(ResponseStatus.MAPPER_ERROR,"添加时数据库访问失败");}
        return Response.ok();
    }

    @Override
    public PageResponse pagePermissions(int page, int rows) {
        Page<Permission> page2 = (Page<Permission>) this.page(new Page<>(page, rows));
        PageBean<Permission> pageBean = PageBean.createSuccess(
                page2.getRecords(),
                page2.getTotal(),
                page2.getSize(),
                page2.getCurrent(),
                page2.getPages());
        return PageResponse.ok(pageBean);
    }

    /**
     * 主要功能：修改已有权限
     * @data 2021/2/20 9:49
     * @author: dl
     * @param	id	权限id
     * @param	permissionStr	新增加权限
     * @return com.gihon.common.http.HttpResult
     *
     */
    @Override
    public Response modifyPermission(Long id, String permissionStr) {
        Permission permission = this.getById(id);
        permission.setName(permissionStr);
        int update = baseMapper.update(permission, new QueryWrapper<Permission>().eq("id", id));

        if (update == 0) {
            return Response.error(ResponseStatus.MAPPER_ERROR);
        }
        return Response.ok();
    }


}
